@@ -417,11 +417,12 @@ class calc_area:
     
     def __init__(self,
                  df,
-                 delarea:float = None
+                 delarea:float = None,
                  ):
         
         self.df = df
         self.delarea = delarea
+        self.area_unit = area_unit
         
         if isinstance(self.df, str):
             data = gpd.read_file(self.df)
